chordtools.Chord
================

.. abjad-lineage:: abjad.tools.chordtools.Chord.Chord.Chord

.. autoclass:: abjad.tools.chordtools.Chord.Chord.Chord

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.chordtools.Chord.Chord.Chord.append
      ~abjad.tools.chordtools.Chord.Chord.Chord.extend
      ~abjad.tools.chordtools.Chord.Chord.Chord.get_note_head
      ~abjad.tools.chordtools.Chord.Chord.Chord.lilypond_duration_multiplier
      ~abjad.tools.chordtools.Chord.Chord.Chord.lilypond_format
      ~abjad.tools.chordtools.Chord.Chord.Chord.note_heads
      ~abjad.tools.chordtools.Chord.Chord.Chord.override
      ~abjad.tools.chordtools.Chord.Chord.Chord.pop
      ~abjad.tools.chordtools.Chord.Chord.Chord.remove
      ~abjad.tools.chordtools.Chord.Chord.Chord.select
      ~abjad.tools.chordtools.Chord.Chord.Chord.set
      ~abjad.tools.chordtools.Chord.Chord.Chord.sounding_pitches
      ~abjad.tools.chordtools.Chord.Chord.Chord.storage_format
      ~abjad.tools.chordtools.Chord.Chord.Chord.written_duration
      ~abjad.tools.chordtools.Chord.Chord.Chord.written_pitch_indication_is_at_sounding_pitch
      ~abjad.tools.chordtools.Chord.Chord.Chord.written_pitch_indication_is_nonsemantic
      ~abjad.tools.chordtools.Chord.Chord.Chord.written_pitches
      ~abjad.tools.chordtools.Chord.Chord.Chord.__contains__
      ~abjad.tools.chordtools.Chord.Chord.Chord.__copy__
      ~abjad.tools.chordtools.Chord.Chord.Chord.__delitem__
      ~abjad.tools.chordtools.Chord.Chord.Chord.__eq__
      ~abjad.tools.chordtools.Chord.Chord.Chord.__getitem__
      ~abjad.tools.chordtools.Chord.Chord.Chord.__len__
      ~abjad.tools.chordtools.Chord.Chord.Chord.__mul__
      ~abjad.tools.chordtools.Chord.Chord.Chord.__ne__
      ~abjad.tools.chordtools.Chord.Chord.Chord.__repr__
      ~abjad.tools.chordtools.Chord.Chord.Chord.__rmul__
      ~abjad.tools.chordtools.Chord.Chord.Chord.__setitem__
      ~abjad.tools.chordtools.Chord.Chord.Chord.__str__

Bases
-----

- :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

- :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.override
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.set
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.sounding_pitches
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.lilypond_duration_multiplier
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.note_heads
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_duration
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_pitch_indication_is_at_sounding_pitch
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_pitch_indication_is_nonsemantic
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_pitches
   :noindex:

Methods
-------

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.append
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.extend
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.get_note_head
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.pop
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.remove
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.select
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__contains__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__copy__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__delitem__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__eq__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__getitem__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__len__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__mul__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__ne__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__repr__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__rmul__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__setitem__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__str__
   :noindex:
